==> huaweicloudsdklakeformation-3.1.96-py2.py3-none-any.whl: huaweicloudsdklakeformation/v1/model/list_lake_formation_instance_tags_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListLakeFormationInstanceTagsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'tags': 'list[ResourceTagParam]',
        'x_request_id': 'str'
    }

    attribute_map = {
        'tags': 'tags',
        'x_request_id': 'X-request-id'
    }

    def __init__(self, tags=None, x_request_id=None):
        """ListLakeFormationInstanceTagsResponse

        The model defined in huaweicloud sdk

        :param tags: 标签
        :type tags: list[:class:`huaweicloudsdklakeformation.v1.ResourceTagParam`]
        :param x_request_id: 
        :type x_request_id: str
        """
        
        super(ListLakeFormationInstanceTagsResponse, self).__init__()

        self._tags = None
        self._x_request_id = None
        self.discriminator = None

        if tags is not None:
            self.tags = tags
        if x_request_id is not None:
            self.x_request_id = x_request_id

    @property
    def tags(self):
        """Gets the tags of this ListLakeFormationInstanceTagsResponse.

        标签

        :return: The tags of this ListLakeFormationInstanceTagsResponse.
        :rtype: list[:class:`huaweicloudsdklakeformation.v1.ResourceTagParam`]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this ListLakeFormationInstanceTagsResponse.

        标签

        :param tags: The tags of this ListLakeFormationInstanceTagsResponse.
        :type tags: list[:class:`huaweicloudsdklakeformation.v1.ResourceTagParam`]
        """
        self._tags = tags

    @property
    def x_request_id(self):
        """Gets the x_request_id of this ListLakeFormationInstanceTagsResponse.

        :return: The x_request_id of this ListLakeFormationInstanceTagsResponse.
        :rtype: str
        """
        return self._x_request_id

    @x_request_id.setter
    def x_request_id(self, x_request_id):
        """Sets the x_request_id of this ListLakeFormationInstanceTagsResponse.

        :param x_request_id: The x_request_id of this ListLakeFormationInstanceTagsResponse.
        :type x_request_id: str
        """
        self._x_request_id = x_request_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListLakeFormationInstanceTagsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdklakeformation-3.1.149-py2.py3-none-any.whl: huaweicloudsdklakeformation/v1/model/list_lake_formation_instance_tags_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListLakeFormationInstanceTagsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'tags': 'list[ResourceTagParam]',
        'x_request_id': 'str'
    }

    attribute_map = {
        'tags': 'tags',
        'x_request_id': 'X-request-id'
    }

    def __init__(self, tags=None, x_request_id=None):
        r"""ListLakeFormationInstanceTagsResponse

        The model defined in huaweicloud sdk

        :param tags: 标签
        :type tags: list[:class:`huaweicloudsdklakeformation.v1.ResourceTagParam`]
        :param x_request_id: 
        :type x_request_id: str
        """
        
        super(ListLakeFormationInstanceTagsResponse, self).__init__()

        self._tags = None
        self._x_request_id = None
        self.discriminator = None

        if tags is not None:
            self.tags = tags
        if x_request_id is not None:
            self.x_request_id = x_request_id

    @property
    def tags(self):
        r"""Gets the tags of this ListLakeFormationInstanceTagsResponse.

        标签

        :return: The tags of this ListLakeFormationInstanceTagsResponse.
        :rtype: list[:class:`huaweicloudsdklakeformation.v1.ResourceTagParam`]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        r"""Sets the tags of this ListLakeFormationInstanceTagsResponse.

        标签

        :param tags: The tags of this ListLakeFormationInstanceTagsResponse.
        :type tags: list[:class:`huaweicloudsdklakeformation.v1.ResourceTagParam`]
        """
        self._tags = tags

    @property
    def x_request_id(self):
        r"""Gets the x_request_id of this ListLakeFormationInstanceTagsResponse.

        :return: The x_request_id of this ListLakeFormationInstanceTagsResponse.
        :rtype: str
        """
        return self._x_request_id

    @x_request_id.setter
    def x_request_id(self, x_request_id):
        r"""Sets the x_request_id of this ListLakeFormationInstanceTagsResponse.

        :param x_request_id: The x_request_id of this ListLakeFormationInstanceTagsResponse.
        :type x_request_id: str
        """
        self._x_request_id = x_request_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListLakeFormationInstanceTagsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
